Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(632)

Unified Diff: ui/views/controls/scrollbar/bitmap_scroll_bar.h

Issue 10382144: Change SetImage, SetBackground, and SetToggledImage to take in a gfx::ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/controls/scrollbar/bitmap_scroll_bar.h
diff --git a/ui/views/controls/scrollbar/bitmap_scroll_bar.h b/ui/views/controls/scrollbar/bitmap_scroll_bar.h
index 3f9ccabdef5c894f2a855357242ad593a4a7b6a8..dde09d131a95972c498e4c9e405c447da9450b48 100644
--- a/ui/views/controls/scrollbar/bitmap_scroll_bar.h
+++ b/ui/views/controls/scrollbar/bitmap_scroll_bar.h
@@ -51,10 +51,10 @@ class VIEWS_EXPORT BitmapScrollBar : public BaseScrollBar,
PART_COUNT
};
// Sets the bitmap to be rendered for the specified part and state.
void SetImage(ScrollBarPart part,
CustomButton::ButtonState state,
- SkBitmap* bitmap);
+ gfx::ImageSkia* image_skia);
gfx::Rect GetTrackBounds() const;
@@ -79,7 +79,7 @@ class VIEWS_EXPORT BitmapScrollBar : public BaseScrollBar,
// The thumb needs to be able to access the part images.
friend BitmapScrollBarThumb;
- SkBitmap* images_[PART_COUNT][CustomButton::BS_COUNT];
+ gfx::ImageSkia* images_[PART_COUNT][CustomButton::BS_COUNT];
// True if the scroll buttons at each end of the scroll bar should be shown.
bool show_scroll_buttons_;
@@ -51,10 +51,10 @@ class VIEWS_EXPORT BitmapScrollBar : public BaseScrollBar,
PART_COUNT
};
- // Sets the bitmap to be rendered for the specified part and state.
+ // Sets the image to be rendered for the specified part and state.
void SetImage(ScrollBarPart part,
CustomButton::ButtonState state,

Powered by Google App Engine
This is Rietveld 408576698